
API Documentation
=================

.. automodule:: tendril.config
    :members:
    :undoc-members:
    :show-inheritance:


Defined Configuration Options
-----------------------------

.. toctree::

    tendril.config.core
    tendril.config.paths


Legacy Configuration Infrastructure
-----------------------------------

.. toctree::

    tendril.config.legacy
